@@ -97,14 +97,23 @@ class KubeModel(ABC):
         self.task = self.args._task
         self.epoch = self.args.epoch
 
+    # def _config_optimizer(self):
+    #     """
+    #     Configures the optimizer specified by the user to be used in training. By default
+    #     it resets the state of the optimizer like the momentum buffer in SGD with momentum
+    #     :return:
+    #     """
+    #     optimizer = self.configure_optimizers()
+    #     self.optimizer = optimizer
+    #     self.logger.debug(f"Configure optimizer at epoch: {self.epoch}")
+
     def _config_optimizer(self):
         """
         Configures the optimizer specified by the user to be used in training. By default
         it resets the state of the optimizer like the momentum buffer in SGD with momentum
         :return:
         """
-        optimizer = self.configure_optimizers()
-        self.optimizer = optimizer
+        self.configure_optimizers()
         self.logger.debug(f"Configure optimizer at epoch: {self.epoch}")
 
         # TODO here the state loaded should be the averaged one not the saved from earlier
@@ -378,7 +387,7 @@ class KubeModel(ABC):
 
         :return: The loss of the epoch, as returned by the user function
         """
-
+        self.logger.debug(f"----------------------Epoch: {self.epoch} Starts---------------------------")
         self._on_train_start()
 
         # Determine the batches that we need to train on and the first subset id
